summaryrefslogtreecommitdiff
path: root/ace/Thread_Control.h
diff options
context:
space:
mode:
authorSteve Huston <shuston@riverace.com>2002-07-02 19:59:51 +0000
committerSteve Huston <shuston@riverace.com>2002-07-02 19:59:51 +0000
commit27847df8de460b35cba30a3560ff1ac5a0968a50 (patch)
treea77769a96ea72729688e1c40978f8f4a5512e0be /ace/Thread_Control.h
parentce8b35ae5b7452eba601a0ed4f7b8d9d0c2584f4 (diff)
downloadATCD-27847df8de460b35cba30a3560ff1ac5a0968a50.tar.gz
ChangeLogTag:Tue Jul 2 11:53:29 2002 Steve Huston <shuston@riverace.com>
Diffstat (limited to 'ace/Thread_Control.h')
-rw-r--r--ace/Thread_Control.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/ace/Thread_Control.h b/ace/Thread_Control.h
index fbf8f0f213f..ed32db58184 100644
--- a/ace/Thread_Control.h
+++ b/ace/Thread_Control.h
@@ -32,14 +32,14 @@ class ACE_Thread_Manager;
* @brief Used to keep track of a thread's activities within its entry
* point function.
*
- * A <ACE_Thread_Manager> uses this class to ensure that threads
+ * A ACE_Thread_Manager uses this class to ensure that threads
* it spawns automatically register and unregister themselves
* with it.
* This class can be stored in thread-specific storage using the
- * <ACE_TSS> wrapper. When a thread exits the
+ * ACE_TSS wrapper. When a thread exits the
* <ACE_TSS::cleanup> function deletes this object, thereby
* ensuring that it gets removed from its associated
- * <ACE_Thread_Manager>.
+ * ACE_Thread_Manager.
*/
class ACE_Export ACE_Thread_Control
{
@@ -53,10 +53,10 @@ public:
/// the thread if <do_thr_exit> is enabled.
~ACE_Thread_Control (void);
- /// Remove this thread from its associated <Thread_Manager> and exit
- /// the thread if <do_thr_exit> is enabled.
- void *exit (void *status,
- int do_thr_exit);
+ /// Remove this thread from its associated ACE_Thread_Manager and exit
+ /// the thread if @a do_thr_exit is enabled.
+ ACE_THR_FUNC_RETURN exit (ACE_THR_FUNC_RETURN status,
+ int do_thr_exit);
/// Store the <Thread_Manager> and use it to register ourselves for
/// correct shutdown.
@@ -70,10 +70,10 @@ public:
ACE_Thread_Manager *thr_mgr (ACE_Thread_Manager *);
/// Set the exit status (and return existing status).
- void *status (void *status);
+ ACE_THR_FUNC_RETURN status (ACE_THR_FUNC_RETURN status);
/// Get the current exit status.
- void *status (void);
+ ACE_THR_FUNC_RETURN status (void);
/// Dump the state of an object.
void dump (void) const;
@@ -86,7 +86,7 @@ private:
ACE_Thread_Manager *tm_;
/// Keeps track of the exit status for the thread.
- void *status_;
+ ACE_THR_FUNC_RETURN status_;
};
# if defined (ACE_HAS_INLINED_OSCALLS)